==> haskell-bytes-0.17.4-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-HG49ZVG6vXpISuvgSaY0wp
key:                  bytes-0.17.4-HG49ZVG6vXpISuvgSaY0wp
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  8b0e5de508171c97ef7d968bfd811646
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-HG49ZVG6vXpISuvgSaY0wp
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-1vcGeOkIoa5AvlzcU4c6YE bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-JPfSbBrFTKBgQKoWbpACz
    scientific-0.3.7.0-H4Og6N92k1lGQSMIPZo0fR text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytes-0.17.4-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.4
visibility:           public
id:                   bytes-0.17.4-4jBiUMLMYxP40i2HdEMU00
key:                  bytes-0.17.4-4jBiUMLMYxP40i2HdEMU00
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  a89dc1b2f0c36ffddd78b9b624524418
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytes-0.17.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.4-4jBiUMLMYxP40i2HdEMU00
depends:
    base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-FQkx2muwupKFAZMmPoF30y bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    hashable-1.4.4.0-4IkOt4KzeSSA3Xc4u5PLaT
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
